@@ -1,6 +1,6 @@
 package App::optex::textconv::ooxml::xslt;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use v5.14;
 use warnings;
@@ -30,6 +30,7 @@ my %styles = (
 ##     for .//w:r {
 ##         for w:t {
 ##             s/w:tab/  /g;
+##             s/w:br/\n/g;
 ##             print value;
 ##         }
 ##     }
@@ -59,6 +60,9 @@ docx => q{
     <xsl:for-each select="w:tab">
       <xsl:text>  </xsl:text>
     </xsl:for-each>
+    <xsl:for-each select="w:br">
+      <xsl:text>&#10;</xsl:text>
+    </xsl:for-each>
   </xsl:template>
 </xsl:stylesheet>
 },
